package sgc.portal.cs.cs0301.persistence;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import sgc.portal.base.util.EasyHashMap;
import sgc.portal.cs.cs0301.dto.CS03010001USearch;
import sgc.portal.cs.cs0301.model.CS03010001U;
import sgc.portal.cs.cs0301.model.CS03010002P;
import sgc.portal.cs.cs0301.model.TcsDeftElpsVo;
import sgc.portal.cs.cs0301.model.TcsDeftVo;

import java.util.List;

@Mapper
public interface CS03010001UMapper {
	
	/*하자리스트*/
	List<EasyHashMap<String, Object>> getDeftList(CS03010001USearch search);
	
	/*하자리스트 카운트*/
	List<EasyHashMap<String, Object>> getDeftCountList(CS03010001USearch search);
	
	/*하자경과리스트*/
	List<EasyHashMap<String, Object>> getDeftElpsList(CS03010001USearch search);
	
	/*접수처리*/
	int insertDeftElps(TcsDeftElpsVo tcsDeftElps);
	int updateDeft(TcsDeftVo tcsDeft);
	
	/*SMS전송처리경과*/
	int insertDeftElpsSms(TcsDeftElpsVo tcsDeftElpsSms);
	
	/*첨부파일*/
	int updateAflId(TcsDeftVo tcsDeft);
	
	/*작업지시서 전송 리스트 조회*/
	List<EasyHashMap<String, Object>> getWorkWkiList(CS03010001USearch search);
	
	/*작업지시서전송 처리경과*/
	int insertDeftElpsWork(TcsDeftElpsVo tcsDeftElpsList);
	
	/*완료처리 리스트 조회*/
	List<EasyHashMap<String, Object>> getDeftCompliteList(CS03010001USearch search);
	
	/*완료처리 처리경과*/
	int insertDeftElpsComplite(TcsDeftElpsVo tcsDeftElpsList);
	int updateDeftComplite(TcsDeftVo tcsDeftList);
}
